@@ -107,7 +107,6 @@ def Mqtt():
         return mqttc
 
 
-
 class Dxr_Subscriber:
     def __init__(self, topic, callback):
         global callback_dit, topic_list_str_pub, topic_list_str_sub
@@ -126,6 +125,20 @@ class Dxr_Subscriber:
         self.mqttc.publish('/topic/' + client_id, retain=True, payload=topic_list_str_pub + topic_list_str_sub)
 
 
+# 定义一个订阅者类的解释器
+class dxr_subscriber:
+
+    def __init__(self, topic):
+        self.func = None
+        self.topic = topic
+
+    def __call__(self, func):
+        # 将函数绑定到解释器上
+        self.func = func
+        Dxr_Subscriber(self.topic, self.func)
+
+
+
 class Dxr_Publisher:
     def __init__(self, topic):
         global publish_dit, topic_list_str_pub, topic_list_str_sub
